@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -125,7 +125,7 @@ bool UMLAttributeDialog::apply()
         m_pNameLE->setText(m_pAttribute->name());
         return false;
     }
-    UMLClassifier * pConcept = m_pAttribute->umlParent()->asUMLClassifier();
+    const UMLClassifier * pConcept = m_pAttribute->umlParent()->asUMLClassifier();
     UMLObject *o = pConcept ? pConcept->findChildObject(name) : 0;
     if (o && o != m_pAttribute) {
         KMessageBox::error(this, i18n("The attribute name you have chosen is already being used in this operation."),
