@@ -33,7 +33,6 @@ public:
       : undo(false),
         tabdiagrams(false),
         newcodegen(false),
-        angularlines(false),
         layoutType(Uml::LayoutType::Undefined),
         footerPrinting(false),
         autosave(false),
@@ -52,7 +51,6 @@ public:
     bool undo;
     bool tabdiagrams;
     bool newcodegen;
-    bool angularlines;
     Uml::LayoutType::Enum layoutType;
     bool footerPrinting;
     bool autosave;
@@ -136,7 +134,7 @@ public:
         defaultAssocFieldScope(Uml::Visibility::Public),
         defaultAttributeAccessorScope(Uml::Visibility::Public),
         forceDoc(false),
-        forceSections(false),
+        writeSectionComments(CodeGenerationPolicy::None),
         includeHeadings(false),
         indentationAmount(false),
         indentationType(CodeGenerationPolicy::NONE),
@@ -160,7 +158,7 @@ public:
     Uml::Visibility::Enum defaultAssocFieldScope;
     Uml::Visibility::Enum defaultAttributeAccessorScope;
     bool forceDoc;
-    bool forceSections;
+    CodeGenerationPolicy::WriteSectionCommentsPolicy writeSectionComments;
     QDir headingsDirectory;
     bool includeHeadings;
     int indentationAmount;
